import typing

import java
import java.lang
import java.net

class ServerSocketFactory(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def createServerSocket(self) -> java.net.ServerSocket: ...
    @typing.overload
    def createServerSocket(self, arg1: int | java.jint | java.lang.Integer, /) -> java.net.ServerSocket: ...
    @typing.overload
    def createServerSocket(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> java.net.ServerSocket: ...
    @typing.overload
    def createServerSocket(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.net.InetAddress, /) -> java.net.ServerSocket: ...
    @staticmethod
    def getDefault() -> ServerSocketFactory: ...

class SocketFactory(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def createSocket(self) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self, arg1: java.net.InetAddress, arg2: int | java.jint | java.lang.Integer, /) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: java.net.InetAddress, arg4: int | java.jint | java.lang.Integer, /) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self, arg1: java.net.InetAddress, arg2: int | java.jint | java.lang.Integer, arg3: java.net.InetAddress, arg4: int | java.jint | java.lang.Integer, /) -> java.net.Socket: ...
    @staticmethod
    def getDefault() -> SocketFactory: ...



import typing

import java
import java.chaquopy
import java.lang
import java.security.cert

class EapAkaInfo(EapInfo):
    def getReauthId(self) -> java.chaquopy.JavaArrayJByte | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> EapAkaInfo: ...
        def setReauthId(self, reauthId: java.chaquopy.JavaArrayJByte, /) -> EapAkaInfo.Builder: ...

class EapInfo(java.lang.Object):
    def getEapMethodType(self) -> int: ...

class EapSessionConfig(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEapAkaConfig(self) -> EapSessionConfig.EapAkaConfig | None: ...
    def getEapAkaPrimeConfig(self) -> EapSessionConfig.EapAkaPrimeConfig | None: ...
    def getEapIdentity(self) -> java.chaquopy.JavaArrayJByte: ...
    def getEapMsChapV2Config(self) -> EapSessionConfig.EapMsChapV2Config | None: ...
    def getEapSimConfig(self) -> EapSessionConfig.EapSimConfig | None: ...
    def getEapTtlsConfig(self) -> EapSessionConfig.EapTtlsConfig | None: ...
    def hashCode(self) -> int: ...

    class EapTtlsConfig(EapSessionConfig.EapMethodConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getInnerEapSessionConfig(self) -> EapSessionConfig: ...
        def getServerCaCert(self) -> java.security.cert.X509Certificate: ...
        def hashCode(self) -> int: ...

    class EapSimConfig(EapSessionConfig.EapMethodConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAppType(self) -> int: ...
        def getSubId(self) -> int: ...
        def hashCode(self) -> int: ...

    class EapMsChapV2Config(EapSessionConfig.EapMethodConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getPassword(self) -> str: ...
        def getUsername(self) -> str: ...
        def hashCode(self) -> int: ...

    class EapMethodConfig(java.lang.Object):
        EAP_TYPE_AKA: typing.ClassVar[int] = ...
        EAP_TYPE_AKA_PRIME: typing.ClassVar[int] = ...
        EAP_TYPE_MSCHAP_V2: typing.ClassVar[int] = ...
        EAP_TYPE_SIM: typing.ClassVar[int] = ...
        EAP_TYPE_TTLS: typing.ClassVar[int] = ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getMethodType(self) -> int: ...
        def hashCode(self) -> int: ...

    class EapAkaPrimeConfig(EapSessionConfig.EapAkaConfig):
        def allowsMismatchedNetworkNames(self) -> bool: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getNetworkName(self) -> str: ...
        def hashCode(self) -> int: ...

    class EapAkaOption(java.lang.Object):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getReauthId(self) -> java.chaquopy.JavaArrayJByte: ...
        def hashCode(self) -> int: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> EapSessionConfig.EapAkaOption: ...
            def setReauthId(self, reauthId: java.chaquopy.JavaArrayJByte, /) -> EapSessionConfig.EapAkaOption.Builder: ...

    class EapAkaConfig(EapSessionConfig.EapMethodConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAppType(self) -> int: ...
        def getEapAkaOption(self) -> EapSessionConfig.EapAkaOption: ...
        def getSubId(self) -> int: ...
        def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> EapSessionConfig: ...
        @typing.overload
        def setEapAkaConfig(self, subId: int | java.jint | java.lang.Integer, apptype: int | java.jint | java.lang.Integer, /) -> EapSessionConfig.Builder: ...
        @typing.overload
        def setEapAkaConfig(self, subId: int | java.jint | java.lang.Integer, apptype: int | java.jint | java.lang.Integer, options: EapSessionConfig.EapAkaOption, /) -> EapSessionConfig.Builder: ...
        def setEapAkaPrimeConfig(self, subId: int | java.jint | java.lang.Integer, apptype: int | java.jint | java.lang.Integer, networkName: str | java.lang.String, allowMismatchedNetworkNames: bool | java.jboolean | java.lang.Boolean, /) -> EapSessionConfig.Builder: ...
        def setEapIdentity(self, eapIdentity: java.chaquopy.JavaArrayJByte, /) -> EapSessionConfig.Builder: ...
        def setEapMsChapV2Config(self, username: str | java.lang.String, password: str | java.lang.String, /) -> EapSessionConfig.Builder: ...
        def setEapSimConfig(self, subId: int | java.jint | java.lang.Integer, apptype: int | java.jint | java.lang.Integer, /) -> EapSessionConfig.Builder: ...
        def setEapTtlsConfig(self, serverCaCert: java.security.cert.X509Certificate, innerEapSessionConfig: EapSessionConfig, /) -> EapSessionConfig.Builder: ...



import typing

import android.app
import android.content
import android.content.res
import android.graphics.drawable
import android.net
import android.os
import android.util
import android.view
import android.widget
import java
import java.chaquopy
import java.lang
import java.util

class CheckBoxPreference(TwoStatePreference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def onBindView(self, view: android.view.View, /) -> None: ...

class DialogPreference(android.content.DialogInterface.OnClickListener, android.content.DialogInterface.OnDismissListener, Preference, PreferenceManager.OnActivityDestroyListener):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDialog(self) -> android.app.Dialog | None: ...
    def getDialogIcon(self) -> android.graphics.drawable.Drawable: ...
    def getDialogLayoutResource(self) -> int: ...
    def getDialogMessage(self) -> java.lang.CharSequence: ...
    def getDialogTitle(self) -> java.lang.CharSequence: ...
    def getNegativeButtonText(self) -> java.lang.CharSequence: ...
    def getPositiveButtonText(self) -> java.lang.CharSequence: ...
    def onActivityDestroy(self) -> None: ...
    def onBindDialogView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def onClick(self) -> None: ...
    @typing.overload
    def onClick(self, dialog: android.content.DialogInterface, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def onCreateDialogView(self) -> android.view.View: ...
    def onDialogClosed(self, positiveResult: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onDismiss(self, dialog: android.content.DialogInterface, /) -> None: ...
    def onPrepareDialogBuilder(self, builder: android.app.AlertDialog.Builder, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    @typing.overload
    def setDialogIcon(self, dialogIconRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDialogIcon(self, dialogIcon: android.graphics.drawable.Drawable, /) -> None: ...
    def setDialogLayoutResource(self, dialogLayoutResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDialogMessage(self, dialogMessageResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDialogMessage(self, dialogMessage: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setDialogTitle(self, dialogTitleResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDialogTitle(self, dialogTitle: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setNegativeButtonText(self, negativeButtonTextResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNegativeButtonText(self, negativeButtonText: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setPositiveButtonText(self, positiveButtonTextResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setPositiveButtonText(self, positiveButtonText: java.lang.CharSequence, /) -> None: ...
    def showDialog(self, state: android.os.Bundle, /) -> None: ...

class EditTextPreference(DialogPreference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getEditText(self) -> android.widget.EditText: ...
    def getText(self) -> str: ...
    def onAddEditTextToDialogView(self, dialogView: android.view.View, editText: android.widget.EditText, /) -> None: ...
    def onBindDialogView(self, view: android.view.View, /) -> None: ...
    def onDialogClosed(self, positiveResult: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSetInitialValue(self, restoreValue: bool | java.jboolean | java.lang.Boolean, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setText(self, text: str | java.lang.String, /) -> None: ...
    def shouldDisableDependents(self) -> bool: ...
    def showDialog(self, state: android.os.Bundle, /) -> None: ...

class ListPreference(DialogPreference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def findIndexOfValue(self, value: str | java.lang.String, /) -> int: ...
    def getEntries(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getEntry(self) -> java.lang.CharSequence | None: ...
    def getEntryValues(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getSummary(self) -> java.lang.CharSequence: ...
    def getValue(self) -> str: ...
    def onDialogClosed(self, positiveResult: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onPrepareDialogBuilder(self, builder: android.app.AlertDialog.Builder, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSetInitialValue(self, restoreValue: bool | java.jboolean | java.lang.Boolean, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setEntries(self, entriesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setEntries(self, entries: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> None: ...
    @typing.overload
    def setEntryValues(self, entryValuesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setEntryValues(self, entryValues: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> None: ...
    def setSummary(self, summary: java.lang.CharSequence, /) -> None: ...
    def setValue(self, value: str | java.lang.String, /) -> None: ...
    def setValueIndex(self, index: int | java.jint | java.lang.Integer, /) -> None: ...

class MultiSelectListPreference(DialogPreference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def findIndexOfValue(self, value: str | java.lang.String, /) -> int: ...
    def getEntries(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getEntryValues(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getValues(self) -> java.util.Set[java.lang.String]: ...
    def onDialogClosed(self, positiveResult: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onPrepareDialogBuilder(self, builder: android.app.AlertDialog.Builder, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSetInitialValue(self, restoreValue: bool | java.jboolean | java.lang.Boolean, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setEntries(self, entriesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setEntries(self, entries: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> None: ...
    @typing.overload
    def setEntryValues(self, entryValuesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setEntryValues(self, entryValues: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> None: ...
    def setValues(self, values: java.util.Set[java.lang.String], /) -> None: ...

class Preference(java.lang.Comparable[Preference]):
    DEFAULT_ORDER: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def callChangeListener(self, newValue: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def compareTo(self, another: Preference, /) -> int: ...
    def findPreferenceInHierarchy(self, key: str | java.lang.String, /) -> Preference: ...
    def getContext(self) -> android.content.Context: ...
    def getDependency(self) -> str: ...
    def getEditor(self) -> android.content.SharedPreferences.Editor: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFragment(self) -> str: ...
    def getIcon(self) -> android.graphics.drawable.Drawable: ...
    def getIntent(self) -> android.content.Intent: ...
    def getKey(self) -> str: ...
    def getLayoutResource(self) -> int: ...
    def getOnPreferenceChangeListener(self) -> Preference.OnPreferenceChangeListener: ...
    def getOnPreferenceClickListener(self) -> Preference.OnPreferenceClickListener: ...
    def getOrder(self) -> int: ...
    def getParent(self) -> PreferenceGroup | None: ...
    def getPersistedBoolean(self, defaultReturnValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getPersistedFloat(self, defaultReturnValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getPersistedInt(self, defaultReturnValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPersistedLong(self, defaultReturnValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getPersistedString(self, defaultReturnValue: str | java.lang.String, /) -> str: ...
    def getPersistedStringSet(self, defaultReturnValue: java.util.Set[java.lang.String], /) -> java.util.Set[java.lang.String]: ...
    def getPreferenceDataStore(self) -> PreferenceDataStore | None: ...
    def getPreferenceManager(self) -> PreferenceManager: ...
    def getSharedPreferences(self) -> android.content.SharedPreferences: ...
    def getShouldDisableView(self) -> bool: ...
    def getSummary(self) -> java.lang.CharSequence: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def getTitleRes(self) -> int: ...
    def getView(self, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getWidgetLayoutResource(self) -> int: ...
    def hasKey(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isIconSpaceReserved(self) -> bool: ...
    def isPersistent(self) -> bool: ...
    def isRecycleEnabled(self) -> bool: ...
    def isSelectable(self) -> bool: ...
    def isSingleLineTitle(self) -> bool: ...
    def notifyChanged(self) -> None: ...
    def notifyDependencyChange(self, disableDependents: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def notifyHierarchyChanged(self) -> None: ...
    def onAttachedToActivity(self) -> None: ...
    def onAttachedToHierarchy(self, preferenceManager: PreferenceManager, /) -> None: ...
    def onBindView(self, view: android.view.View, /) -> None: ...
    def onClick(self) -> None: ...
    def onCreateView(self, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def onDependencyChanged(self, dependency: Preference, disableDependent: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onParentChanged(self, parent: Preference, disableChild: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPrepareForRemoval(self) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSetInitialValue(self, restorePersistedValue: bool | java.jboolean | java.lang.Boolean, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    def peekExtras(self) -> android.os.Bundle: ...
    def persistBoolean(self, value: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def persistFloat(self, value: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def persistInt(self, value: int | java.jint | java.lang.Integer, /) -> bool: ...
    def persistLong(self, value: int | java.jlong | java.lang.Long, /) -> bool: ...
    def persistString(self, value: str | java.lang.String, /) -> bool: ...
    def persistStringSet(self, values: java.util.Set[java.lang.String], /) -> bool: ...
    def restoreHierarchyState(self, container: android.os.Bundle, /) -> None: ...
    def saveHierarchyState(self, container: android.os.Bundle, /) -> None: ...
    def setDefaultValue(self, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setDependency(self, dependencyKey: str | java.lang.String, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFragment(self, fragment: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setIcon(self, iconResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setIconSpaceReserved(self, iconSpaceReserved: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIntent(self, intent: android.content.Intent, /) -> None: ...
    def setKey(self, key: str | java.lang.String, /) -> None: ...
    def setLayoutResource(self, layoutResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnPreferenceChangeListener(self, onPreferenceChangeListener: Preference.OnPreferenceChangeListener, /) -> None: ...
    def setOnPreferenceClickListener(self, onPreferenceClickListener: Preference.OnPreferenceClickListener, /) -> None: ...
    def setOrder(self, order: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPersistent(self, persistent: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPreferenceDataStore(self, dataStore: PreferenceDataStore, /) -> None: ...
    def setRecycleEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelectable(self, selectable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShouldDisableView(self, shouldDisableView: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSingleLineTitle(self, singleLineTitle: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setSummary(self, summaryResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSummary(self, summary: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setTitle(self, titleResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
    def setWidgetLayoutResource(self, widgetLayoutResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def shouldCommit(self) -> bool: ...
    def shouldDisableDependents(self) -> bool: ...
    def shouldPersist(self) -> bool: ...
    def toString(self) -> str: ...

    class OnPreferenceClickListener(java.lang.Object):
        def onPreferenceClick(self, arg1: Preference, /) -> bool: ...

    class OnPreferenceChangeListener(java.lang.Object):
        def onPreferenceChange(self, arg1: Preference, arg2: java.lang.Object | int | bool | float | str, /) -> bool: ...

    class BaseSavedState(android.view.AbsSavedState):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Preference.BaseSavedState]] = ...
        @typing.overload
        def __init__(self, source: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, superState: android.os.Parcelable, /) -> None: ...

class PreferenceActivity(android.app.ListActivity, PreferenceFragment.OnPreferenceStartFragmentCallback):
    EXTRA_NO_HEADERS: typing.ClassVar[str] = ...
    EXTRA_SHOW_FRAGMENT: typing.ClassVar[str] = ...
    EXTRA_SHOW_FRAGMENT_ARGUMENTS: typing.ClassVar[str] = ...
    EXTRA_SHOW_FRAGMENT_SHORT_TITLE: typing.ClassVar[str] = ...
    EXTRA_SHOW_FRAGMENT_TITLE: typing.ClassVar[str] = ...
    HEADER_ID_UNDEFINED: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addPreferencesFromIntent(self, intent: android.content.Intent, /) -> None: ...
    def addPreferencesFromResource(self, preferencesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def findPreference(self, key: java.lang.CharSequence, /) -> Preference: ...
    def finishPreferencePanel(self, caller: android.app.Fragment, resultCode: int | java.jint | java.lang.Integer, resultData: android.content.Intent, /) -> None: ...
    def getPreferenceManager(self) -> PreferenceManager: ...
    def getPreferenceScreen(self) -> PreferenceScreen: ...
    def hasHeaders(self) -> bool: ...
    def invalidateHeaders(self) -> None: ...
    def isMultiPane(self) -> bool: ...
    def isValidFragment(self, fragmentName: str | java.lang.String, /) -> bool: ...
    def loadHeadersFromResource(self, resid: int | java.jint | java.lang.Integer, target: java.util.List[PreferenceActivity.Header], /) -> None: ...
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    def onBackPressed(self) -> None: ...
    def onBuildHeaders(self, target: java.util.List[PreferenceActivity.Header], /) -> None: ...
    def onBuildStartFragmentIntent(self, fragmentName: str | java.lang.String, args: android.os.Bundle, titleRes: int | java.jint | java.lang.Integer, shortTitleRes: int | java.jint | java.lang.Integer, /) -> android.content.Intent: ...
    def onContentChanged(self) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onDestroy(self) -> None: ...
    def onGetInitialHeader(self) -> PreferenceActivity.Header: ...
    def onGetNewHeader(self) -> PreferenceActivity.Header: ...
    def onHeaderClick(self, header: PreferenceActivity.Header, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def onIsHidingHeaders(self) -> bool: ...
    def onIsMultiPane(self) -> bool: ...
    def onListItemClick(self, l: android.widget.ListView, v: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...
    def onNewIntent(self, intent: android.content.Intent, /) -> None: ...
    def onOptionsItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onPreferenceStartFragment(self, caller: PreferenceFragment, pref: Preference, /) -> bool: ...
    def onPreferenceTreeClick(self, preferenceScreen: PreferenceScreen, preference: Preference, /) -> bool: ...
    def onRestoreInstanceState(self, state: android.os.Bundle, /) -> None: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStop(self) -> None: ...
    def setListFooter(self, view: android.view.View, /) -> None: ...
    def setParentTitle(self, title: java.lang.CharSequence, shortTitle: java.lang.CharSequence, listener: android.view.View.OnClickListener, /) -> None: ...
    def setPreferenceScreen(self, preferenceScreen: PreferenceScreen, /) -> None: ...
    def showBreadCrumbs(self, title: java.lang.CharSequence, shortTitle: java.lang.CharSequence, /) -> None: ...
    def startPreferenceFragment(self, fragment: android.app.Fragment, push: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startPreferencePanel(self, fragmentClass: str | java.lang.String, args: android.os.Bundle, titleRes: int | java.jint | java.lang.Integer, titleText: java.lang.CharSequence, resultTo: android.app.Fragment, resultRequestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startWithFragment(self, fragmentName: str | java.lang.String, args: android.os.Bundle, resultTo: android.app.Fragment, resultRequestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startWithFragment(self, fragmentName: str | java.lang.String, args: android.os.Bundle, resultTo: android.app.Fragment, resultRequestCode: int | java.jint | java.lang.Integer, titleRes: int | java.jint | java.lang.Integer, shortTitleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def switchToHeader(self, header: PreferenceActivity.Header, /) -> None: ...
    @typing.overload
    def switchToHeader(self, fragmentName: str | java.lang.String, args: android.os.Bundle, /) -> None: ...

    class Header(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PreferenceActivity.Header]] = ...
        breadCrumbShortTitle: java.lang.CharSequence = ...
        breadCrumbShortTitleRes: int = ...
        breadCrumbTitle: java.lang.CharSequence = ...
        breadCrumbTitleRes: int = ...
        extras: android.os.Bundle = ...
        fragment: str = ...
        fragmentArguments: android.os.Bundle = ...
        iconRes: int = ...
        id: int = ...
        intent: android.content.Intent = ...
        summary: java.lang.CharSequence = ...
        summaryRes: int = ...
        title: java.lang.CharSequence = ...
        titleRes: int = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def getBreadCrumbShortTitle(self, res: android.content.res.Resources, /) -> java.lang.CharSequence: ...
        def getBreadCrumbTitle(self, res: android.content.res.Resources, /) -> java.lang.CharSequence: ...
        def getSummary(self, res: android.content.res.Resources, /) -> java.lang.CharSequence: ...
        def getTitle(self, res: android.content.res.Resources, /) -> java.lang.CharSequence: ...
        def readFromParcel(self, in_: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PreferenceCategory(PreferenceGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def isEnabled(self) -> bool: ...
    def onPrepareAddPreference(self, preference: Preference, /) -> bool: ...
    def shouldDisableDependents(self) -> bool: ...

class PreferenceDataStore(java.lang.Object):
    def getBoolean(self, key: str | java.lang.String, defValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getFloat(self, key: str | java.lang.String, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getInt(self, key: str | java.lang.String, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, key: str | java.lang.String, defValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getString(self, key: str | java.lang.String, defValue: str | java.lang.String, /) -> str | None: ...
    def getStringSet(self, key: str | java.lang.String, defValues: java.util.Set[java.lang.String], /) -> java.util.Set[java.lang.String] | None: ...
    def putBoolean(self, key: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def putFloat(self, key: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> None: ...
    def putInt(self, key: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def putLong(self, key: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def putString(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def putStringSet(self, key: str | java.lang.String, values: java.util.Set[java.lang.String], /) -> None: ...

class PreferenceFragment(android.app.Fragment):
    def __init__(self) -> None: ...
    def addPreferencesFromIntent(self, intent: android.content.Intent, /) -> None: ...
    def addPreferencesFromResource(self, preferencesResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def findPreference(self, key: java.lang.CharSequence, /) -> Preference: ...
    def getPreferenceManager(self) -> PreferenceManager: ...
    def getPreferenceScreen(self) -> PreferenceScreen: ...
    def onActivityCreated(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onCreateView(self, inflater: android.view.LayoutInflater, container: android.view.ViewGroup, savedInstanceState: android.os.Bundle, /) -> android.view.View: ...
    def onDestroy(self) -> None: ...
    def onDestroyView(self) -> None: ...
    def onPreferenceTreeClick(self, preferenceScreen: PreferenceScreen, preference: Preference, /) -> bool: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def onViewCreated(self, view: android.view.View, savedInstanceState: android.os.Bundle, /) -> None: ...
    def setPreferenceScreen(self, preferenceScreen: PreferenceScreen, /) -> None: ...

    class OnPreferenceStartFragmentCallback(java.lang.Object):
        def onPreferenceStartFragment(self, arg1: PreferenceFragment, arg2: Preference, /) -> bool: ...

class PreferenceGroup(Preference):
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addItemFromInflater(self, preference: Preference, /) -> None: ...
    def addPreference(self, preference: Preference, /) -> bool: ...
    def dispatchRestoreInstanceState(self, container: android.os.Bundle, /) -> None: ...
    def dispatchSaveInstanceState(self, container: android.os.Bundle, /) -> None: ...
    def findPreference(self, key: java.lang.CharSequence, /) -> Preference: ...
    def getPreference(self, index: int | java.jint | java.lang.Integer, /) -> Preference: ...
    def getPreferenceCount(self) -> int: ...
    def isOnSameScreenAsChildren(self) -> bool: ...
    def isOrderingAsAdded(self) -> bool: ...
    def notifyDependencyChange(self, disableDependents: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onAttachedToActivity(self) -> None: ...
    def onPrepareAddPreference(self, preference: Preference, /) -> bool: ...
    def onPrepareForRemoval(self) -> None: ...
    def removeAll(self) -> None: ...
    def removePreference(self, preference: Preference, /) -> bool: ...
    def setOrderingAsAdded(self, orderingAsAdded: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class PreferenceManager(java.lang.Object):
    KEY_HAS_SET_DEFAULT_VALUES: typing.ClassVar[str] = ...
    METADATA_KEY_PREFERENCES: typing.ClassVar[str] = ...
    def createPreferenceScreen(self, context: android.content.Context, /) -> PreferenceScreen: ...
    def findPreference(self, key: java.lang.CharSequence, /) -> Preference | None: ...
    @staticmethod
    def getDefaultSharedPreferences(context: android.content.Context, /) -> android.content.SharedPreferences: ...
    @staticmethod
    def getDefaultSharedPreferencesName(context: android.content.Context, /) -> str: ...
    def getPreferenceDataStore(self) -> PreferenceDataStore | None: ...
    def getSharedPreferences(self) -> android.content.SharedPreferences: ...
    def getSharedPreferencesMode(self) -> int: ...
    def getSharedPreferencesName(self) -> str: ...
    def isStorageDefault(self) -> bool: ...
    def isStorageDeviceProtected(self) -> bool: ...
    @typing.overload
    @staticmethod
    def setDefaultValues(context: android.content.Context, resId: int | java.jint | java.lang.Integer, readAgain: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    @staticmethod
    def setDefaultValues(context: android.content.Context, sharedPreferencesName: str | java.lang.String, sharedPreferencesMode: int | java.jint | java.lang.Integer, resId: int | java.jint | java.lang.Integer, readAgain: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPreferenceDataStore(self, dataStore: PreferenceDataStore, /) -> None: ...
    def setSharedPreferencesMode(self, sharedPreferencesMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSharedPreferencesName(self, sharedPreferencesName: str | java.lang.String, /) -> None: ...
    def setStorageDefault(self) -> None: ...
    def setStorageDeviceProtected(self) -> None: ...

    class OnActivityStopListener(java.lang.Object):
        def onActivityStop(self) -> None: ...

    class OnActivityResultListener(java.lang.Object):
        def onActivityResult(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: android.content.Intent, /) -> bool: ...

    class OnActivityDestroyListener(java.lang.Object):
        def onActivityDestroy(self) -> None: ...

class PreferenceScreen(android.content.DialogInterface.OnDismissListener, PreferenceGroup, android.widget.AdapterView.OnItemClickListener):
    def bind(self, listView: android.widget.ListView, /) -> None: ...
    def getDialog(self) -> android.app.Dialog: ...
    def getRootAdapter(self) -> android.widget.ListAdapter: ...
    def isOnSameScreenAsChildren(self) -> bool: ...
    def onClick(self) -> None: ...
    def onCreateRootAdapter(self) -> android.widget.ListAdapter: ...
    def onDismiss(self, dialog: android.content.DialogInterface, /) -> None: ...
    def onItemClick(self, parent: android.widget.AdapterView, view: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...

class RingtonePreference(Preference, PreferenceManager.OnActivityResultListener):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getRingtoneType(self) -> int: ...
    def getShowDefault(self) -> bool: ...
    def getShowSilent(self) -> bool: ...
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> bool: ...
    def onAttachedToHierarchy(self, preferenceManager: PreferenceManager, /) -> None: ...
    def onClick(self) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onPrepareRingtonePickerIntent(self, ringtonePickerIntent: android.content.Intent, /) -> None: ...
    def onRestoreRingtone(self) -> android.net.Uri: ...
    def onSaveRingtone(self, ringtoneUri: android.net.Uri, /) -> None: ...
    def onSetInitialValue(self, restorePersistedValue: bool | java.jboolean | java.lang.Boolean, defaultValueObj: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setRingtoneType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShowDefault(self, showDefault: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowSilent(self, showSilent: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class SwitchPreference(TwoStatePreference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSwitchTextOff(self) -> java.lang.CharSequence: ...
    def getSwitchTextOn(self) -> java.lang.CharSequence: ...
    def onBindView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setSwitchTextOff(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSwitchTextOff(self, offText: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setSwitchTextOn(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSwitchTextOn(self, onText: java.lang.CharSequence, /) -> None: ...

class TwoStatePreference(Preference):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDisableDependentsState(self) -> bool: ...
    def getSummaryOff(self) -> java.lang.CharSequence: ...
    def getSummaryOn(self) -> java.lang.CharSequence: ...
    def isChecked(self) -> bool: ...
    def onClick(self) -> None: ...
    def onGetDefaultValue(self, a: android.content.res.TypedArray, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSetInitialValue(self, restoreValue: bool | java.jboolean | java.lang.Boolean, defaultValue: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisableDependentsState(self, disableDependentsState: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setSummaryOff(self, summaryResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSummaryOff(self, summary: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setSummaryOn(self, summaryResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSummaryOn(self, summary: java.lang.CharSequence, /) -> None: ...
    def shouldDisableDependents(self) -> bool: ...



import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.io
import java.lang
import java.util
import java.util.concurrent

class OnObbStateChangeListener(java.lang.Object):
    ERROR_ALREADY_MOUNTED: typing.ClassVar[int] = ...
    ERROR_COULD_NOT_MOUNT: typing.ClassVar[int] = ...
    ERROR_COULD_NOT_UNMOUNT: typing.ClassVar[int] = ...
    ERROR_INTERNAL: typing.ClassVar[int] = ...
    ERROR_NOT_MOUNTED: typing.ClassVar[int] = ...
    ERROR_PERMISSION_DENIED: typing.ClassVar[int] = ...
    MOUNTED: typing.ClassVar[int] = ...
    UNMOUNTED: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onObbStateChange(self, path: str | java.lang.String, state: int | java.jint | java.lang.Integer, /) -> None: ...

class StorageManager(java.lang.Object):
    ACTION_CLEAR_APP_CACHE: typing.ClassVar[str] = ...
    ACTION_MANAGE_STORAGE: typing.ClassVar[str] = ...
    EXTRA_REQUESTED_BYTES: typing.ClassVar[str] = ...
    EXTRA_UUID: typing.ClassVar[str] = ...
    UUID_DEFAULT: typing.ClassVar[java.util.UUID] = ...
    @typing.overload
    def allocateBytes(self, fd: java.io.FileDescriptor, bytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def allocateBytes(self, storageUuid: java.util.UUID, bytes: int | java.jlong | java.lang.Long, /) -> None: ...
    def getAllocatableBytes(self, storageUuid: java.util.UUID, /) -> int: ...
    def getCacheQuotaBytes(self, storageUuid: java.util.UUID, /) -> int: ...
    def getCacheSizeBytes(self, storageUuid: java.util.UUID, /) -> int: ...
    def getManageSpaceActivityIntent(self, packageName: str | java.lang.String, requestCode: int | java.jint | java.lang.Integer, /) -> android.app.PendingIntent | None: ...
    def getMountedObbPath(self, rawPath: str | java.lang.String, /) -> str: ...
    def getPrimaryStorageVolume(self) -> StorageVolume: ...
    def getRecentStorageVolumes(self) -> java.util.List[StorageVolume]: ...
    @typing.overload
    def getStorageVolume(self, uri: android.net.Uri, /) -> StorageVolume | None: ...
    @typing.overload
    def getStorageVolume(self, file: java.io.File, /) -> StorageVolume | None: ...
    def getStorageVolumes(self) -> java.util.List[StorageVolume]: ...
    def getStorageVolumesIncludingSharedProfiles(self) -> java.util.List[StorageVolume]: ...
    def getUuidForPath(self, path: java.io.File, /) -> java.util.UUID: ...
    def isAllocationSupported(self, fd: java.io.FileDescriptor, /) -> bool: ...
    def isCacheBehaviorGroup(self, path: java.io.File, /) -> bool: ...
    def isCacheBehaviorTombstone(self, path: java.io.File, /) -> bool: ...
    def isCheckpointSupported(self) -> bool: ...
    def isEncrypted(self, file: java.io.File, /) -> bool: ...
    def isObbMounted(self, rawPath: str | java.lang.String, /) -> bool: ...
    def mountObb(self, rawPath: str | java.lang.String, key: str | java.lang.String, listener: OnObbStateChangeListener, /) -> bool: ...
    def openProxyFileDescriptor(self, mode: int | java.jint | java.lang.Integer, callback: android.os.ProxyFileDescriptorCallback, handler: android.os.Handler, /) -> android.os.ParcelFileDescriptor: ...
    def registerStorageVolumeCallback(self, executor: java.util.concurrent.Executor, callback: StorageManager.StorageVolumeCallback, /) -> None: ...
    def setCacheBehaviorGroup(self, path: java.io.File, group: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCacheBehaviorTombstone(self, path: java.io.File, tombstone: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def unmountObb(self, rawPath: str | java.lang.String, force: bool | java.jboolean | java.lang.Boolean, listener: OnObbStateChangeListener, /) -> bool: ...
    def unregisterStorageVolumeCallback(self, callback: StorageManager.StorageVolumeCallback, /) -> None: ...

    class StorageVolumeCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onStateChanged(self, volume: StorageVolume, /) -> None: ...

class StorageVolume(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StorageVolume]] = ...
    EXTRA_STORAGE_VOLUME: typing.ClassVar[str] = ...
    def createAccessIntent(self, directoryName: str | java.lang.String, /) -> android.content.Intent | None: ...
    def createOpenDocumentTreeIntent(self) -> android.content.Intent: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescription(self, context: android.content.Context, /) -> str: ...
    def getDirectory(self) -> java.io.File | None: ...
    def getMediaStoreVolumeName(self) -> str | None: ...
    def getOwner(self) -> android.os.UserHandle: ...
    def getState(self) -> str: ...
    def getStorageUuid(self) -> java.util.UUID | None: ...
    def getUuid(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def isEmulated(self) -> bool: ...
    def isPrimary(self) -> bool: ...
    def isRemovable(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.graphics.drawable
import android.os
import java
import java.lang

class ControlButton(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ControlButton]] = ...
    def __init__(self, checked: bool | java.jboolean | java.lang.Boolean, actionDescription: java.lang.CharSequence, /) -> None: ...
    def describeContents(self) -> int: ...
    def getActionDescription(self) -> java.lang.CharSequence: ...
    def isChecked(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ControlTemplate(java.lang.Object):
    TYPE_ERROR: typing.ClassVar[int] = ...
    TYPE_NO_TEMPLATE: typing.ClassVar[int] = ...
    TYPE_RANGE: typing.ClassVar[int] = ...
    TYPE_STATELESS: typing.ClassVar[int] = ...
    TYPE_TEMPERATURE: typing.ClassVar[int] = ...
    TYPE_THUMBNAIL: typing.ClassVar[int] = ...
    TYPE_TOGGLE: typing.ClassVar[int] = ...
    TYPE_TOGGLE_RANGE: typing.ClassVar[int] = ...
    @staticmethod
    def getErrorTemplate() -> ControlTemplate: ...
    @staticmethod
    def getNoTemplateObject() -> ControlTemplate: ...
    def getTemplateId(self) -> str: ...
    def getTemplateType(self) -> int: ...

class RangeTemplate(ControlTemplate):
    def __init__(self, templateId: str | java.lang.String, minValue: float | java.jfloat | java.lang.Float, maxValue: float | java.jfloat | java.lang.Float, currentValue: float | java.jfloat | java.lang.Float, stepValue: float | java.jfloat | java.lang.Float, formatString: java.lang.CharSequence, /) -> None: ...
    def getCurrentValue(self) -> float: ...
    def getFormatString(self) -> java.lang.CharSequence: ...
    def getMaxValue(self) -> float: ...
    def getMinValue(self) -> float: ...
    def getStepValue(self) -> float: ...
    def getTemplateType(self) -> int: ...

class StatelessTemplate(ControlTemplate):
    def __init__(self, templateId: str | java.lang.String, /) -> None: ...
    def getTemplateType(self) -> int: ...

class TemperatureControlTemplate(ControlTemplate):
    FLAG_MODE_COOL: typing.ClassVar[int] = ...
    FLAG_MODE_ECO: typing.ClassVar[int] = ...
    FLAG_MODE_HEAT: typing.ClassVar[int] = ...
    FLAG_MODE_HEAT_COOL: typing.ClassVar[int] = ...
    FLAG_MODE_OFF: typing.ClassVar[int] = ...
    MODE_COOL: typing.ClassVar[int] = ...
    MODE_ECO: typing.ClassVar[int] = ...
    MODE_HEAT: typing.ClassVar[int] = ...
    MODE_HEAT_COOL: typing.ClassVar[int] = ...
    MODE_OFF: typing.ClassVar[int] = ...
    MODE_UNKNOWN: typing.ClassVar[int] = ...
    def __init__(self, templateId: str | java.lang.String, controlTemplate: ControlTemplate, currentMode: int | java.jint | java.lang.Integer, currentActiveMode: int | java.jint | java.lang.Integer, modesFlag: int | java.jint | java.lang.Integer, /) -> None: ...
    def getCurrentActiveMode(self) -> int: ...
    def getCurrentMode(self) -> int: ...
    def getModes(self) -> int: ...
    def getTemplate(self) -> ControlTemplate: ...
    def getTemplateType(self) -> int: ...

class ThumbnailTemplate(ControlTemplate):
    def __init__(self, templateId: str | java.lang.String, active: bool | java.jboolean | java.lang.Boolean, thumbnail: android.graphics.drawable.Icon, contentDescription: java.lang.CharSequence, /) -> None: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getTemplateType(self) -> int: ...
    def getThumbnail(self) -> android.graphics.drawable.Icon: ...
    def isActive(self) -> bool: ...

class ToggleRangeTemplate(ControlTemplate):
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, button: ControlButton, range: RangeTemplate, /) -> None: ...
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, checked: bool | java.jboolean | java.lang.Boolean, actionDescription: java.lang.CharSequence, range: RangeTemplate, /) -> None: ...
    def getActionDescription(self) -> java.lang.CharSequence: ...
    def getRange(self) -> RangeTemplate: ...
    def getTemplateType(self) -> int: ...
    def isChecked(self) -> bool: ...

class ToggleTemplate(ControlTemplate):
    def __init__(self, templateId: str | java.lang.String, button: ControlButton, /) -> None: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getTemplateType(self) -> int: ...
    def isChecked(self) -> bool: ...



import typing

import android.content
import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class EncryptedTopic(java.lang.Object):
    def __init__(self, encryptedTopic: java.chaquopy.JavaArrayJByte, keyIdentifier: str | java.lang.String, encapsulatedKey: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEncapsulatedKey(self) -> java.chaquopy.JavaArrayJByte: ...
    def getEncryptedTopic(self) -> java.chaquopy.JavaArrayJByte: ...
    def getKeyIdentifier(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class GetTopicsRequest(java.lang.Object):
    def getAdsSdkName(self) -> str: ...
    def shouldRecordObservation(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> GetTopicsRequest: ...
        def setAdsSdkName(self, adsSdkName: str | java.lang.String, /) -> GetTopicsRequest.Builder: ...
        def setShouldRecordObservation(self, recordObservation: bool | java.jboolean | java.lang.Boolean, /) -> GetTopicsRequest.Builder: ...

class GetTopicsResponse(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEncryptedTopics(self) -> java.util.List[EncryptedTopic]: ...
    def getTopics(self) -> java.util.List[Topic]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, topics: java.util.List[Topic], /) -> None: ...
        @typing.overload
        def __init__(self, topics: java.util.List[Topic], encryptedTopics: java.util.List[EncryptedTopic], /) -> None: ...
        def build(self) -> GetTopicsResponse: ...

class Topic(java.lang.Object):
    def __init__(self, mTaxonomyVersion: int | java.jlong | java.lang.Long, mModelVersion: int | java.jlong | java.lang.Long, mTopicId: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getModelVersion(self) -> int: ...
    def getTaxonomyVersion(self) -> int: ...
    def getTopicId(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class TopicsManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> TopicsManager: ...
    def getTopics(self, getTopicsRequest: GetTopicsRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[GetTopicsResponse, java.lang.Exception], /) -> None: ...



import typing

import android.os
import java
import java.chaquopy
import java.lang
import java.time
import java.util

class UwbAddress(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UwbAddress]] = ...
    EXTENDED_ADDRESS_BYTE_LENGTH: typing.ClassVar[int] = ...
    SHORT_ADDRESS_BYTE_LENGTH: typing.ClassVar[int] = ...
    @staticmethod
    def createRandomShortAddress() -> UwbAddress: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromBytes(address: java.chaquopy.JavaArrayJByte, /) -> UwbAddress: ...
    def getAddressBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UwbComplexChannel(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UwbComplexChannel]] = ...
    UWB_CHANNEL_10: typing.ClassVar[int] = ...
    UWB_CHANNEL_12: typing.ClassVar[int] = ...
    UWB_CHANNEL_13: typing.ClassVar[int] = ...
    UWB_CHANNEL_14: typing.ClassVar[int] = ...
    UWB_CHANNEL_5: typing.ClassVar[int] = ...
    UWB_CHANNEL_6: typing.ClassVar[int] = ...
    UWB_CHANNEL_8: typing.ClassVar[int] = ...
    UWB_CHANNEL_9: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_10: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_11: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_12: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_25: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_26: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_27: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_28: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_29: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_30: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_31: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_32: typing.ClassVar[int] = ...
    UWB_PREAMBLE_CODE_INDEX_9: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChannel(self) -> int: ...
    def getPreambleIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> UwbComplexChannel: ...
        def setChannel(self, channel: int | java.jint | java.lang.Integer, /) -> UwbComplexChannel.Builder: ...
        def setPreambleIndex(self, preambleIndex: int | java.jint | java.lang.Integer, /) -> UwbComplexChannel.Builder: ...

class UwbRangingCapabilities(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UwbRangingCapabilities]] = ...
    def describeContents(self) -> int: ...
    def getMinimumRangingInterval(self) -> java.time.Duration: ...
    def getSupportedChannels(self) -> java.util.List[java.lang.Integer]: ...
    def getSupportedConfigIds(self) -> java.util.List[java.lang.Integer]: ...
    def getSupportedNotificationConfigurations(self) -> java.util.List[java.lang.Integer]: ...
    def getSupportedPreambleIndexes(self) -> java.util.List[java.lang.Integer]: ...
    def getSupportedRangingUpdateRates(self) -> java.util.List[java.lang.Integer]: ...
    def getSupportedSlotDurations(self) -> java.util.List[java.lang.Integer]: ...
    def isAzimuthalAngleSupported(self) -> bool: ...
    def isBackgroundRangingSupported(self) -> bool: ...
    def isDistanceMeasurementSupported(self) -> bool: ...
    def isElevationAngleSupported(self) -> bool: ...
    def isRangingIntervalReconfigurationSupported(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UwbRangingParams(android.os.Parcelable):
    CONFIG_MULTICAST_DS_TWR: typing.ClassVar[int] = ...
    CONFIG_PROVISIONED_INDIVIDUAL_MULTICAST_DS_TWR: typing.ClassVar[int] = ...
    CONFIG_PROVISIONED_MULTICAST_DS_TWR: typing.ClassVar[int] = ...
    CONFIG_PROVISIONED_UNICAST_DS_TWR: typing.ClassVar[int] = ...
    CONFIG_PROVISIONED_UNICAST_DS_TWR_VERY_FAST: typing.ClassVar[int] = ...
    CONFIG_UNICAST_DS_TWR: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UwbRangingParams]] = ...
    DURATION_1_MS: typing.ClassVar[int] = ...
    DURATION_2_MS: typing.ClassVar[int] = ...
    SUB_SESSION_UNDEFINED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getComplexChannel(self) -> UwbComplexChannel: ...
    def getConfigId(self) -> int: ...
    def getDeviceAddress(self) -> UwbAddress: ...
    def getPeerAddress(self) -> UwbAddress: ...
    def getRangingUpdateRate(self) -> int: ...
    def getSessionId(self) -> int: ...
    def getSessionKeyInfo(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSlotDuration(self) -> int: ...
    def getSubSessionId(self) -> int: ...
    def getSubSessionKeyInfo(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, sessionId: int | java.jint | java.lang.Integer, configId: int | java.jint | java.lang.Integer, deviceAddress: UwbAddress, peerAddress: UwbAddress, /) -> None: ...
        def build(self) -> UwbRangingParams: ...
        def setComplexChannel(self, complexChannel: UwbComplexChannel, /) -> UwbRangingParams.Builder: ...
        def setRangingUpdateRate(self, rate: int | java.jint | java.lang.Integer, /) -> UwbRangingParams.Builder: ...
        def setSessionKeyInfo(self, sessionKeyInfo: java.chaquopy.JavaArrayJByte, /) -> UwbRangingParams.Builder: ...
        def setSlotDuration(self, durationMs: int | java.jint | java.lang.Integer, /) -> UwbRangingParams.Builder: ...
        def setSubSessionId(self, subSessionId: int | java.jint | java.lang.Integer, /) -> UwbRangingParams.Builder: ...
        def setSubSessionKeyInfo(self, subSessionKeyInfo: java.chaquopy.JavaArrayJByte, /) -> UwbRangingParams.Builder: ...



import typing

import java
import java.io
import java.lang
import java.math
import java.util
import javax.xml.namespace

class DatatypeConfigurationException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def printStackTrace(self) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintStream, /) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintWriter, /) -> None: ...

class DatatypeConstants(java.lang.Object):
    APRIL: typing.ClassVar[int] = ...
    AUGUST: typing.ClassVar[int] = ...
    DATE: typing.ClassVar[javax.xml.namespace.QName] = ...
    DATETIME: typing.ClassVar[javax.xml.namespace.QName] = ...
    DAYS: typing.ClassVar[DatatypeConstants.Field] = ...
    DECEMBER: typing.ClassVar[int] = ...
    DURATION: typing.ClassVar[javax.xml.namespace.QName] = ...
    DURATION_DAYTIME: typing.ClassVar[javax.xml.namespace.QName] = ...
    DURATION_YEARMONTH: typing.ClassVar[javax.xml.namespace.QName] = ...
    EQUAL: typing.ClassVar[int] = ...
    FEBRUARY: typing.ClassVar[int] = ...
    FIELD_UNDEFINED: typing.ClassVar[int] = ...
    GDAY: typing.ClassVar[javax.xml.namespace.QName] = ...
    GMONTH: typing.ClassVar[javax.xml.namespace.QName] = ...
    GMONTHDAY: typing.ClassVar[javax.xml.namespace.QName] = ...
    GREATER: typing.ClassVar[int] = ...
    GYEAR: typing.ClassVar[javax.xml.namespace.QName] = ...
    GYEARMONTH: typing.ClassVar[javax.xml.namespace.QName] = ...
    HOURS: typing.ClassVar[DatatypeConstants.Field] = ...
    INDETERMINATE: typing.ClassVar[int] = ...
    JANUARY: typing.ClassVar[int] = ...
    JULY: typing.ClassVar[int] = ...
    JUNE: typing.ClassVar[int] = ...
    LESSER: typing.ClassVar[int] = ...
    MARCH: typing.ClassVar[int] = ...
    MAX_TIMEZONE_OFFSET: typing.ClassVar[int] = ...
    MAY: typing.ClassVar[int] = ...
    MINUTES: typing.ClassVar[DatatypeConstants.Field] = ...
    MIN_TIMEZONE_OFFSET: typing.ClassVar[int] = ...
    MONTHS: typing.ClassVar[DatatypeConstants.Field] = ...
    NOVEMBER: typing.ClassVar[int] = ...
    OCTOBER: typing.ClassVar[int] = ...
    SECONDS: typing.ClassVar[DatatypeConstants.Field] = ...
    SEPTEMBER: typing.ClassVar[int] = ...
    TIME: typing.ClassVar[javax.xml.namespace.QName] = ...
    YEARS: typing.ClassVar[DatatypeConstants.Field] = ...

    class Field(java.lang.Object):
        def getId(self) -> int: ...
        def toString(self) -> str: ...

class DatatypeFactory(java.lang.Object):
    DATATYPEFACTORY_IMPLEMENTATION_CLASS: typing.ClassVar[str] = ...
    DATATYPEFACTORY_PROPERTY: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @typing.overload
    def newDuration(self, arg1: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    def newDuration(self, arg1: str | java.lang.String, /) -> Duration: ...
    @typing.overload
    def newDuration(self, isPositive: bool | java.jboolean | java.lang.Boolean, years: int | java.jint | java.lang.Integer, months: int | java.jint | java.lang.Integer, days: int | java.jint | java.lang.Integer, hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, seconds: int | java.jint | java.lang.Integer, /) -> Duration: ...
    @typing.overload
    def newDuration(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: java.math.BigInteger, arg3: java.math.BigInteger, arg4: java.math.BigInteger, arg5: java.math.BigInteger, arg6: java.math.BigInteger, arg7: java.math.BigDecimal, /) -> Duration: ...
    @typing.overload
    def newDurationDayTime(self, durationInMilliseconds: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    def newDurationDayTime(self, lexicalRepresentation: str | java.lang.String, /) -> Duration: ...
    @typing.overload
    def newDurationDayTime(self, isPositive: bool | java.jboolean | java.lang.Boolean, day: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> Duration: ...
    @typing.overload
    def newDurationDayTime(self, isPositive: bool | java.jboolean | java.lang.Boolean, day: java.math.BigInteger, hour: java.math.BigInteger, minute: java.math.BigInteger, second: java.math.BigInteger, /) -> Duration: ...
    @typing.overload
    def newDurationYearMonth(self, durationInMilliseconds: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    def newDurationYearMonth(self, lexicalRepresentation: str | java.lang.String, /) -> Duration: ...
    @typing.overload
    def newDurationYearMonth(self, isPositive: bool | java.jboolean | java.lang.Boolean, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, /) -> Duration: ...
    @typing.overload
    def newDurationYearMonth(self, isPositive: bool | java.jboolean | java.lang.Boolean, year: java.math.BigInteger, month: java.math.BigInteger, /) -> Duration: ...
    @typing.overload
    @staticmethod
    def newInstance() -> DatatypeFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(factoryClassName: str | java.lang.String, classLoader: java.lang.ClassLoader, /) -> DatatypeFactory: ...
    @typing.overload
    def newXMLGregorianCalendar(self) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendar(self, arg1: str | java.lang.String, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendar(self, arg1: java.util.GregorianCalendar, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendar(self, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, day: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, millisecond: int | java.jint | java.lang.Integer, timezone: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendar(self, arg1: java.math.BigInteger, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: java.math.BigDecimal, arg8: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...
    def newXMLGregorianCalendarDate(self, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, day: int | java.jint | java.lang.Integer, timezone: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendarTime(self, hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, seconds: int | java.jint | java.lang.Integer, timezone: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendarTime(self, hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, seconds: int | java.jint | java.lang.Integer, milliseconds: int | java.jint | java.lang.Integer, timezone: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...
    @typing.overload
    def newXMLGregorianCalendarTime(self, hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, seconds: int | java.jint | java.lang.Integer, fractionalSecond: java.math.BigDecimal, timezone: int | java.jint | java.lang.Integer, /) -> XMLGregorianCalendar: ...

class Duration(java.lang.Object):
    def __init__(self) -> None: ...
    def add(self, arg1: Duration, /) -> Duration: ...
    @typing.overload
    def addTo(self, arg1: java.util.Calendar, /) -> None: ...
    @typing.overload
    def addTo(self, date: java.util.Date, /) -> None: ...
    def compare(self, arg1: Duration, /) -> int: ...
    def equals(self, duration: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDays(self) -> int: ...
    def getField(self, arg1: DatatypeConstants.Field, /) -> java.lang.Number: ...
    def getHours(self) -> int: ...
    def getMinutes(self) -> int: ...
    def getMonths(self) -> int: ...
    def getSeconds(self) -> int: ...
    def getSign(self) -> int: ...
    @typing.overload
    def getTimeInMillis(self, startInstant: java.util.Calendar, /) -> int: ...
    @typing.overload
    def getTimeInMillis(self, startInstant: java.util.Date, /) -> int: ...
    def getXMLSchemaType(self) -> javax.xml.namespace.QName: ...
    def getYears(self) -> int: ...
    def hashCode(self) -> int: ...
    def isLongerThan(self, duration: Duration, /) -> bool: ...
    def isSet(self, arg1: DatatypeConstants.Field, /) -> bool: ...
    def isShorterThan(self, duration: Duration, /) -> bool: ...
    @typing.overload
    def multiply(self, factor: int | java.jint | java.lang.Integer, /) -> Duration: ...
    @typing.overload
    def multiply(self, arg1: java.math.BigDecimal, /) -> Duration: ...
    def negate(self) -> Duration: ...
    def normalizeWith(self, arg1: java.util.Calendar, /) -> Duration: ...
    def subtract(self, rhs: Duration, /) -> Duration: ...
    def toString(self) -> str: ...

class XMLGregorianCalendar(java.lang.Cloneable):
    def __init__(self) -> None: ...
    def add(self, arg1: Duration, /) -> None: ...
    def clear(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def compare(self, arg1: XMLGregorianCalendar, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDay(self) -> int: ...
    def getEon(self) -> java.math.BigInteger: ...
    def getEonAndYear(self) -> java.math.BigInteger: ...
    def getFractionalSecond(self) -> java.math.BigDecimal: ...
    def getHour(self) -> int: ...
    def getMillisecond(self) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> int: ...
    def getSecond(self) -> int: ...
    def getTimeZone(self, arg1: int | java.jint | java.lang.Integer, /) -> java.util.TimeZone: ...
    def getTimezone(self) -> int: ...
    def getXMLSchemaType(self) -> javax.xml.namespace.QName: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isValid(self) -> bool: ...
    def normalize(self) -> XMLGregorianCalendar: ...
    def reset(self) -> None: ...
    def setDay(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFractionalSecond(self, arg1: java.math.BigDecimal, /) -> None: ...
    def setHour(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMillisecond(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinute(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMonth(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSecond(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, millisecond: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, fractional: java.math.BigDecimal, /) -> None: ...
    def setTimezone(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setYear(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setYear(self, arg1: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def toGregorianCalendar(self) -> java.util.GregorianCalendar: ...
    @typing.overload
    def toGregorianCalendar(self, arg1: java.util.TimeZone, arg2: java.util.Locale, arg3: XMLGregorianCalendar, /) -> java.util.GregorianCalendar: ...
    def toString(self) -> str: ...
    def toXMLFormat(self) -> str: ...



import typing

import android.app
import android.app.slice
import android.content
import android.content.pm
import android.credentials
import android.os
import java
import java.lang
import java.util

class Action(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Action]] = ...
    def __init__(self, slice: android.app.slice.Slice, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSlice(self) -> android.app.slice.Slice: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BeginCreateCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BeginCreateCredentialRequest]] = ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, data: android.os.Bundle, callingAppInfo: CallingAppInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCallingAppInfo(self) -> CallingAppInfo | None: ...
    def getData(self) -> android.os.Bundle: ...
    def getType(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BeginCreateCredentialResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BeginCreateCredentialResponse]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getCreateEntries(self) -> java.util.List[CreateEntry]: ...
    def getRemoteCreateEntry(self) -> RemoteEntry | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addCreateEntry(self, createEntry: CreateEntry, /) -> BeginCreateCredentialResponse.Builder: ...
        def build(self) -> BeginCreateCredentialResponse: ...
        def setCreateEntries(self, createEntries: java.util.List[CreateEntry], /) -> BeginCreateCredentialResponse.Builder: ...
        def setRemoteCreateEntry(self, remoteCreateEntry: RemoteEntry, /) -> BeginCreateCredentialResponse.Builder: ...

class BeginGetCredentialOption(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BeginGetCredentialOption]] = ...
    def __init__(self, id: str | java.lang.String, type: str | java.lang.String, candidateQueryData: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCandidateQueryData(self) -> android.os.Bundle: ...
    def getId(self) -> str: ...
    def getType(self) -> str: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BeginGetCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BeginGetCredentialRequest]] = ...
    def describeContents(self) -> int: ...
    def getBeginGetCredentialOptions(self) -> java.util.List[BeginGetCredentialOption]: ...
    def getCallingAppInfo(self) -> CallingAppInfo | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addBeginGetCredentialOption(self, beginGetCredentialOption: BeginGetCredentialOption, /) -> BeginGetCredentialRequest.Builder: ...
        def build(self) -> BeginGetCredentialRequest: ...
        def setBeginGetCredentialOptions(self, getBeginCredentialOptions: java.util.List[BeginGetCredentialOption], /) -> BeginGetCredentialRequest.Builder: ...
        def setCallingAppInfo(self, callingAppInfo: CallingAppInfo, /) -> BeginGetCredentialRequest.Builder: ...

class BeginGetCredentialResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BeginGetCredentialResponse]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getActions(self) -> java.util.List[Action]: ...
    def getAuthenticationActions(self) -> java.util.List[Action]: ...
    def getCredentialEntries(self) -> java.util.List[CredentialEntry]: ...
    def getRemoteCredentialEntry(self) -> RemoteEntry | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addAction(self, action: Action, /) -> BeginGetCredentialResponse.Builder: ...
        def addAuthenticationAction(self, authenticationAction: Action, /) -> BeginGetCredentialResponse.Builder: ...
        def addCredentialEntry(self, credentialEntry: CredentialEntry, /) -> BeginGetCredentialResponse.Builder: ...
        def build(self) -> BeginGetCredentialResponse: ...
        def setActions(self, actions: java.util.List[Action], /) -> BeginGetCredentialResponse.Builder: ...
        def setAuthenticationActions(self, authenticationActions: java.util.List[Action], /) -> BeginGetCredentialResponse.Builder: ...
        def setCredentialEntries(self, credentialEntries: java.util.List[CredentialEntry], /) -> BeginGetCredentialResponse.Builder: ...
        def setRemoteCredentialEntry(self, remoteCredentialEntry: RemoteEntry, /) -> BeginGetCredentialResponse.Builder: ...

class CallingAppInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CallingAppInfo]] = ...
    @typing.overload
    def __init__(self, packageName: str | java.lang.String, signingInfo: android.content.pm.SigningInfo, /) -> None: ...
    @typing.overload
    def __init__(self, packageName: str | java.lang.String, signingInfo: android.content.pm.SigningInfo, origin: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getOrigin(self) -> str | None: ...
    def getPackageName(self) -> str: ...
    def getSigningInfo(self) -> android.content.pm.SigningInfo: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ClearCredentialStateRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ClearCredentialStateRequest]] = ...
    def __init__(self, callingAppInfo: CallingAppInfo, data: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCallingAppInfo(self) -> CallingAppInfo: ...
    def getData(self) -> android.os.Bundle: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CreateCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CreateCredentialRequest]] = ...
    def __init__(self, callingAppInfo: CallingAppInfo, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCallingAppInfo(self) -> CallingAppInfo: ...
    def getData(self) -> android.os.Bundle: ...
    def getType(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CreateEntry(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CreateEntry]] = ...
    def __init__(self, slice: android.app.slice.Slice, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSlice(self) -> android.app.slice.Slice: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CredentialEntry(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CredentialEntry]] = ...
    @typing.overload
    def __init__(self, beginGetCredentialOption: BeginGetCredentialOption, slice: android.app.slice.Slice, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, slice: android.app.slice.Slice, /) -> None: ...
    @typing.overload
    def __init__(self, beginGetCredentialOptionId: str | java.lang.String, type: str | java.lang.String, slice: android.app.slice.Slice, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBeginGetCredentialOptionId(self) -> str: ...
    def getSlice(self) -> android.app.slice.Slice: ...
    def getType(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CredentialProviderService(android.app.Service):
    EXTRA_BEGIN_GET_CREDENTIAL_REQUEST: typing.ClassVar[str] = ...
    EXTRA_BEGIN_GET_CREDENTIAL_RESPONSE: typing.ClassVar[str] = ...
    EXTRA_CREATE_CREDENTIAL_EXCEPTION: typing.ClassVar[str] = ...
    EXTRA_CREATE_CREDENTIAL_REQUEST: typing.ClassVar[str] = ...
    EXTRA_CREATE_CREDENTIAL_RESPONSE: typing.ClassVar[str] = ...
    EXTRA_GET_CREDENTIAL_EXCEPTION: typing.ClassVar[str] = ...
    EXTRA_GET_CREDENTIAL_REQUEST: typing.ClassVar[str] = ...
    EXTRA_GET_CREDENTIAL_RESPONSE: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBeginCreateCredential(self, arg1: BeginCreateCredentialRequest, arg2: android.os.CancellationSignal, arg3: android.os.OutcomeReceiver[BeginCreateCredentialResponse, android.credentials.CreateCredentialException], /) -> None: ...
    def onBeginGetCredential(self, arg1: BeginGetCredentialRequest, arg2: android.os.CancellationSignal, arg3: android.os.OutcomeReceiver[BeginGetCredentialResponse, android.credentials.GetCredentialException], /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onClearCredentialState(self, arg1: ClearCredentialStateRequest, arg2: android.os.CancellationSignal, arg3: android.os.OutcomeReceiver[java.lang.Void, android.credentials.ClearCredentialStateException], /) -> None: ...
    def onCreate(self) -> None: ...

class GetCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetCredentialRequest]] = ...
    def __init__(self, callingAppInfo: CallingAppInfo, credentialOptions: java.util.List[android.credentials.CredentialOption], /) -> None: ...
    def describeContents(self) -> int: ...
    def getCallingAppInfo(self) -> CallingAppInfo: ...
    def getCredentialOptions(self) -> java.util.List[android.credentials.CredentialOption]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RemoteEntry(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RemoteEntry]] = ...
    def __init__(self, slice: android.app.slice.Slice, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSlice(self) -> android.app.slice.Slice: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import android.graphics
import java
import java.chaquopy
import java.lang

class ArcShape(RectShape):
    def __init__(self, startAngle: float | java.jfloat | java.lang.Float, sweepAngle: float | java.jfloat | java.lang.Float, /) -> None: ...
    def clone(self) -> ArcShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def getStartAngle(self) -> float: ...
    def getSweepAngle(self) -> float: ...
    def hashCode(self) -> int: ...

class OvalShape(RectShape):
    def __init__(self) -> None: ...
    def clone(self) -> OvalShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...

class PathShape(Shape):
    def __init__(self, path: android.graphics.Path, stdWidth: float | java.jfloat | java.lang.Float, stdHeight: float | java.jfloat | java.lang.Float, /) -> None: ...
    def clone(self) -> PathShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...

class RectShape(Shape):
    def __init__(self) -> None: ...
    def clone(self) -> RectShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...
    def rect(self) -> android.graphics.RectF: ...

class RoundRectShape(RectShape):
    def __init__(self, outerRadii: java.chaquopy.JavaArrayJFloat, inset: android.graphics.RectF, innerRadii: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def clone(self) -> RoundRectShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def hashCode(self) -> int: ...
    def onResize(self, w: float | java.jfloat | java.lang.Float, h: float | java.jfloat | java.lang.Float, /) -> None: ...

class Shape(java.lang.Cloneable):
    def __init__(self) -> None: ...
    def clone(self) -> Shape: ...
    def draw(self, arg1: android.graphics.Canvas, arg2: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHeight(self) -> float: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def getWidth(self) -> float: ...
    def hasAlpha(self) -> bool: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...
    def resize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.text
import java.util

class NumericShaper(java.io.Serializable):
    ALL_RANGES: typing.ClassVar[int] = ...
    ARABIC: typing.ClassVar[int] = ...
    BENGALI: typing.ClassVar[int] = ...
    DEVANAGARI: typing.ClassVar[int] = ...
    EASTERN_ARABIC: typing.ClassVar[int] = ...
    ETHIOPIC: typing.ClassVar[int] = ...
    EUROPEAN: typing.ClassVar[int] = ...
    GUJARATI: typing.ClassVar[int] = ...
    GURMUKHI: typing.ClassVar[int] = ...
    KANNADA: typing.ClassVar[int] = ...
    KHMER: typing.ClassVar[int] = ...
    LAO: typing.ClassVar[int] = ...
    MALAYALAM: typing.ClassVar[int] = ...
    MONGOLIAN: typing.ClassVar[int] = ...
    MYANMAR: typing.ClassVar[int] = ...
    ORIYA: typing.ClassVar[int] = ...
    TAMIL: typing.ClassVar[int] = ...
    TELUGU: typing.ClassVar[int] = ...
    THAI: typing.ClassVar[int] = ...
    TIBETAN: typing.ClassVar[int] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    @staticmethod
    def getContextualShaper(ranges: int | java.jint | java.lang.Integer, /) -> NumericShaper: ...
    @typing.overload
    @staticmethod
    def getContextualShaper(ranges: java.util.Set[NumericShaper.Range], /) -> NumericShaper: ...
    @typing.overload
    @staticmethod
    def getContextualShaper(ranges: int | java.jint | java.lang.Integer, defaultContext: int | java.jint | java.lang.Integer, /) -> NumericShaper: ...
    @typing.overload
    @staticmethod
    def getContextualShaper(ranges: java.util.Set[NumericShaper.Range], defaultContext: NumericShaper.Range, /) -> NumericShaper: ...
    def getRangeSet(self) -> java.util.Set[NumericShaper.Range]: ...
    def getRanges(self) -> int: ...
    @typing.overload
    @staticmethod
    def getShaper(singleRange: int | java.jint | java.lang.Integer, /) -> NumericShaper: ...
    @typing.overload
    @staticmethod
    def getShaper(singleRange: NumericShaper.Range, /) -> NumericShaper: ...
    def hashCode(self) -> int: ...
    def isContextual(self) -> bool: ...
    @typing.overload
    def shape(self, text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def shape(self, text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, context: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def shape(self, text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, context: NumericShaper.Range, /) -> None: ...
    def toString(self) -> str: ...

    class Range(java.lang.Enum[NumericShaper.Range]):
        ARABIC: typing.ClassVar[NumericShaper.Range] = ...
        BALINESE: typing.ClassVar[NumericShaper.Range] = ...
        BENGALI: typing.ClassVar[NumericShaper.Range] = ...
        CHAM: typing.ClassVar[NumericShaper.Range] = ...
        DEVANAGARI: typing.ClassVar[NumericShaper.Range] = ...
        EASTERN_ARABIC: typing.ClassVar[NumericShaper.Range] = ...
        ETHIOPIC: typing.ClassVar[NumericShaper.Range] = ...
        EUROPEAN: typing.ClassVar[NumericShaper.Range] = ...
        GUJARATI: typing.ClassVar[NumericShaper.Range] = ...
        GURMUKHI: typing.ClassVar[NumericShaper.Range] = ...
        JAVANESE: typing.ClassVar[NumericShaper.Range] = ...
        KANNADA: typing.ClassVar[NumericShaper.Range] = ...
        KAYAH_LI: typing.ClassVar[NumericShaper.Range] = ...
        KHMER: typing.ClassVar[NumericShaper.Range] = ...
        LAO: typing.ClassVar[NumericShaper.Range] = ...
        LEPCHA: typing.ClassVar[NumericShaper.Range] = ...
        LIMBU: typing.ClassVar[NumericShaper.Range] = ...
        MALAYALAM: typing.ClassVar[NumericShaper.Range] = ...
        MEETEI_MAYEK: typing.ClassVar[NumericShaper.Range] = ...
        MONGOLIAN: typing.ClassVar[NumericShaper.Range] = ...
        MYANMAR: typing.ClassVar[NumericShaper.Range] = ...
        MYANMAR_SHAN: typing.ClassVar[NumericShaper.Range] = ...
        NEW_TAI_LUE: typing.ClassVar[NumericShaper.Range] = ...
        NKO: typing.ClassVar[NumericShaper.Range] = ...
        OL_CHIKI: typing.ClassVar[NumericShaper.Range] = ...
        ORIYA: typing.ClassVar[NumericShaper.Range] = ...
        SAURASHTRA: typing.ClassVar[NumericShaper.Range] = ...
        SUNDANESE: typing.ClassVar[NumericShaper.Range] = ...
        TAI_THAM_HORA: typing.ClassVar[NumericShaper.Range] = ...
        TAI_THAM_THAM: typing.ClassVar[NumericShaper.Range] = ...
        TAMIL: typing.ClassVar[NumericShaper.Range] = ...
        TELUGU: typing.ClassVar[NumericShaper.Range] = ...
        THAI: typing.ClassVar[NumericShaper.Range] = ...
        TIBETAN: typing.ClassVar[NumericShaper.Range] = ...
        VAI: typing.ClassVar[NumericShaper.Range] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumericShaper.Range: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumericShaper.Range]: ...

class TextAttribute(java.text.AttributedCharacterIterator.Attribute):
    BACKGROUND: typing.ClassVar[TextAttribute] = ...
    BIDI_EMBEDDING: typing.ClassVar[TextAttribute] = ...
    CHAR_REPLACEMENT: typing.ClassVar[TextAttribute] = ...
    FAMILY: typing.ClassVar[TextAttribute] = ...
    FONT: typing.ClassVar[TextAttribute] = ...
    FOREGROUND: typing.ClassVar[TextAttribute] = ...
    INPUT_METHOD_HIGHLIGHT: typing.ClassVar[TextAttribute] = ...
    INPUT_METHOD_UNDERLINE: typing.ClassVar[TextAttribute] = ...
    JUSTIFICATION: typing.ClassVar[TextAttribute] = ...
    JUSTIFICATION_FULL: typing.ClassVar[float] = ...
    JUSTIFICATION_NONE: typing.ClassVar[float] = ...
    KERNING: typing.ClassVar[TextAttribute] = ...
    KERNING_ON: typing.ClassVar[int] = ...
    LIGATURES: typing.ClassVar[TextAttribute] = ...
    LIGATURES_ON: typing.ClassVar[int] = ...
    NUMERIC_SHAPING: typing.ClassVar[TextAttribute] = ...
    POSTURE: typing.ClassVar[TextAttribute] = ...
    POSTURE_OBLIQUE: typing.ClassVar[float] = ...
    POSTURE_REGULAR: typing.ClassVar[float] = ...
    RUN_DIRECTION: typing.ClassVar[TextAttribute] = ...
    RUN_DIRECTION_LTR: typing.ClassVar[bool] = ...
    RUN_DIRECTION_RTL: typing.ClassVar[bool] = ...
    SIZE: typing.ClassVar[TextAttribute] = ...
    STRIKETHROUGH: typing.ClassVar[TextAttribute] = ...
    STRIKETHROUGH_ON: typing.ClassVar[bool] = ...
    SUPERSCRIPT: typing.ClassVar[TextAttribute] = ...
    SUPERSCRIPT_SUB: typing.ClassVar[int] = ...
    SUPERSCRIPT_SUPER: typing.ClassVar[int] = ...
    SWAP_COLORS: typing.ClassVar[TextAttribute] = ...
    SWAP_COLORS_ON: typing.ClassVar[bool] = ...
    TRACKING: typing.ClassVar[TextAttribute] = ...
    TRACKING_LOOSE: typing.ClassVar[float] = ...
    TRACKING_TIGHT: typing.ClassVar[float] = ...
    TRANSFORM: typing.ClassVar[TextAttribute] = ...
    UNDERLINE: typing.ClassVar[TextAttribute] = ...
    UNDERLINE_LOW_DASHED: typing.ClassVar[int] = ...
    UNDERLINE_LOW_DOTTED: typing.ClassVar[int] = ...
    UNDERLINE_LOW_GRAY: typing.ClassVar[int] = ...
    UNDERLINE_LOW_ONE_PIXEL: typing.ClassVar[int] = ...
    UNDERLINE_LOW_TWO_PIXEL: typing.ClassVar[int] = ...
    UNDERLINE_ON: typing.ClassVar[int] = ...
    WEIGHT: typing.ClassVar[TextAttribute] = ...
    WEIGHT_BOLD: typing.ClassVar[float] = ...
    WEIGHT_DEMIBOLD: typing.ClassVar[float] = ...
    WEIGHT_DEMILIGHT: typing.ClassVar[float] = ...
    WEIGHT_EXTRABOLD: typing.ClassVar[float] = ...
    WEIGHT_EXTRA_LIGHT: typing.ClassVar[float] = ...
    WEIGHT_HEAVY: typing.ClassVar[float] = ...
    WEIGHT_LIGHT: typing.ClassVar[float] = ...
    WEIGHT_MEDIUM: typing.ClassVar[float] = ...
    WEIGHT_REGULAR: typing.ClassVar[float] = ...
    WEIGHT_SEMIBOLD: typing.ClassVar[float] = ...
    WEIGHT_ULTRABOLD: typing.ClassVar[float] = ...
    WIDTH: typing.ClassVar[TextAttribute] = ...
    WIDTH_CONDENSED: typing.ClassVar[float] = ...
    WIDTH_EXTENDED: typing.ClassVar[float] = ...
    WIDTH_REGULAR: typing.ClassVar[float] = ...
    WIDTH_SEMI_CONDENSED: typing.ClassVar[float] = ...
    WIDTH_SEMI_EXTENDED: typing.ClassVar[float] = ...
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def readResolve(self) -> java.lang.Object: ...



import typing

import android.app
import android.bluetooth
import android.os
import android.util
import java
import java.chaquopy
import java.lang
import java.util

class AdvertiseCallback(java.lang.Object):
    ADVERTISE_FAILED_ALREADY_STARTED: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_DATA_TOO_LARGE: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_FEATURE_UNSUPPORTED: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_INTERNAL_ERROR: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_TOO_MANY_ADVERTISERS: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onStartFailure(self, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartSuccess(self, settingsInEffect: AdvertiseSettings, /) -> None: ...

class AdvertiseData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdvertiseData]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIncludeDeviceName(self) -> bool: ...
    def getIncludeTxPowerLevel(self) -> bool: ...
    def getManufacturerSpecificData(self) -> android.util.SparseArray[java.chaquopy.JavaArrayJByte]: ...
    def getServiceData(self) -> java.util.Map[android.os.ParcelUuid, java.chaquopy.JavaArrayJByte]: ...
    def getServiceSolicitationUuids(self) -> java.util.List[android.os.ParcelUuid]: ...
    def getServiceUuids(self) -> java.util.List[android.os.ParcelUuid]: ...
    def getTransportDiscoveryData(self) -> java.util.List[TransportDiscoveryData]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addManufacturerData(self, manufacturerId: int | java.jint | java.lang.Integer, manufacturerSpecificData: java.chaquopy.JavaArrayJByte, /) -> AdvertiseData.Builder: ...
        def addServiceData(self, serviceDataUuid: android.os.ParcelUuid, serviceData: java.chaquopy.JavaArrayJByte, /) -> AdvertiseData.Builder: ...
        def addServiceSolicitationUuid(self, serviceSolicitationUuid: android.os.ParcelUuid, /) -> AdvertiseData.Builder: ...
        def addServiceUuid(self, serviceUuid: android.os.ParcelUuid, /) -> AdvertiseData.Builder: ...
        def addTransportDiscoveryData(self, transportDiscoveryData: TransportDiscoveryData, /) -> AdvertiseData.Builder: ...
        def build(self) -> AdvertiseData: ...
        def setIncludeDeviceName(self, includeDeviceName: bool | java.jboolean | java.lang.Boolean, /) -> AdvertiseData.Builder: ...
        def setIncludeTxPowerLevel(self, includeTxPowerLevel: bool | java.jboolean | java.lang.Boolean, /) -> AdvertiseData.Builder: ...

class AdvertiseSettings(android.os.Parcelable):
    ADVERTISE_MODE_BALANCED: typing.ClassVar[int] = ...
    ADVERTISE_MODE_LOW_LATENCY: typing.ClassVar[int] = ...
    ADVERTISE_MODE_LOW_POWER: typing.ClassVar[int] = ...
    ADVERTISE_TX_POWER_HIGH: typing.ClassVar[int] = ...
    ADVERTISE_TX_POWER_LOW: typing.ClassVar[int] = ...
    ADVERTISE_TX_POWER_MEDIUM: typing.ClassVar[int] = ...
    ADVERTISE_TX_POWER_ULTRA_LOW: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdvertiseSettings]] = ...
    def describeContents(self) -> int: ...
    def getMode(self) -> int: ...
    def getTimeout(self) -> int: ...
    def getTxPowerLevel(self) -> int: ...
    def isConnectable(self) -> bool: ...
    def isDiscoverable(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdvertiseSettings: ...
        def setAdvertiseMode(self, advertiseMode: int | java.jint | java.lang.Integer, /) -> AdvertiseSettings.Builder: ...
        def setConnectable(self, connectable: bool | java.jboolean | java.lang.Boolean, /) -> AdvertiseSettings.Builder: ...
        def setDiscoverable(self, discoverable: bool | java.jboolean | java.lang.Boolean, /) -> AdvertiseSettings.Builder: ...
        def setTimeout(self, timeoutMillis: int | java.jint | java.lang.Integer, /) -> AdvertiseSettings.Builder: ...
        def setTxPowerLevel(self, txPowerLevel: int | java.jint | java.lang.Integer, /) -> AdvertiseSettings.Builder: ...

class AdvertisingSet(java.lang.Object):
    def enableAdvertising(self, enable: bool | java.jboolean | java.lang.Boolean, duration: int | java.jint | java.lang.Integer, maxExtendedAdvertisingEvents: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAdvertisingData(self, advertiseData: AdvertiseData, /) -> None: ...
    def setAdvertisingParameters(self, parameters: AdvertisingSetParameters, /) -> None: ...
    def setPeriodicAdvertisingData(self, periodicData: AdvertiseData, /) -> None: ...
    def setPeriodicAdvertisingEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPeriodicAdvertisingParameters(self, parameters: PeriodicAdvertisingParameters, /) -> None: ...
    def setScanResponseData(self, scanResponse: AdvertiseData, /) -> None: ...

class AdvertisingSetCallback(java.lang.Object):
    ADVERTISE_FAILED_ALREADY_STARTED: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_DATA_TOO_LARGE: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_FEATURE_UNSUPPORTED: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_INTERNAL_ERROR: typing.ClassVar[int] = ...
    ADVERTISE_FAILED_TOO_MANY_ADVERTISERS: typing.ClassVar[int] = ...
    ADVERTISE_SUCCESS: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onAdvertisingDataSet(self, advertisingSet: AdvertisingSet, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAdvertisingEnabled(self, advertisingSet: AdvertisingSet, enable: bool | java.jboolean | java.lang.Boolean, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAdvertisingParametersUpdated(self, advertisingSet: AdvertisingSet, txPower: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAdvertisingSetStarted(self, advertisingSet: AdvertisingSet, txPower: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAdvertisingSetStopped(self, advertisingSet: AdvertisingSet, /) -> None: ...
    def onPeriodicAdvertisingDataSet(self, advertisingSet: AdvertisingSet, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPeriodicAdvertisingEnabled(self, advertisingSet: AdvertisingSet, enable: bool | java.jboolean | java.lang.Boolean, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPeriodicAdvertisingParametersUpdated(self, advertisingSet: AdvertisingSet, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onScanResponseDataSet(self, advertisingSet: AdvertisingSet, status: int | java.jint | java.lang.Integer, /) -> None: ...

class AdvertisingSetParameters(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdvertisingSetParameters]] = ...
    INTERVAL_HIGH: typing.ClassVar[int] = ...
    INTERVAL_LOW: typing.ClassVar[int] = ...
    INTERVAL_MAX: typing.ClassVar[int] = ...
    INTERVAL_MEDIUM: typing.ClassVar[int] = ...
    INTERVAL_MIN: typing.ClassVar[int] = ...
    TX_POWER_HIGH: typing.ClassVar[int] = ...
    TX_POWER_LOW: typing.ClassVar[int] = ...
    TX_POWER_MAX: typing.ClassVar[int] = ...
    TX_POWER_MEDIUM: typing.ClassVar[int] = ...
    TX_POWER_MIN: typing.ClassVar[int] = ...
    TX_POWER_ULTRA_LOW: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getInterval(self) -> int: ...
    def getPrimaryPhy(self) -> int: ...
    def getSecondaryPhy(self) -> int: ...
    def getTxPowerLevel(self) -> int: ...
    def includeTxPower(self) -> bool: ...
    def isAnonymous(self) -> bool: ...
    def isConnectable(self) -> bool: ...
    def isDiscoverable(self) -> bool: ...
    def isLegacy(self) -> bool: ...
    def isScannable(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdvertisingSetParameters: ...
        def setAnonymous(self, isAnonymous: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setConnectable(self, connectable: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setDiscoverable(self, discoverable: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setIncludeTxPower(self, includeTxPower: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setInterval(self, interval: int | java.jint | java.lang.Integer, /) -> AdvertisingSetParameters.Builder: ...
        def setLegacyMode(self, isLegacy: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setPrimaryPhy(self, primaryPhy: int | java.jint | java.lang.Integer, /) -> AdvertisingSetParameters.Builder: ...
        def setScannable(self, scannable: bool | java.jboolean | java.lang.Boolean, /) -> AdvertisingSetParameters.Builder: ...
        def setSecondaryPhy(self, secondaryPhy: int | java.jint | java.lang.Integer, /) -> AdvertisingSetParameters.Builder: ...
        def setTxPowerLevel(self, txPowerLevel: int | java.jint | java.lang.Integer, /) -> AdvertisingSetParameters.Builder: ...

class BluetoothLeAdvertiser(java.lang.Object):
    @typing.overload
    def startAdvertising(self, settings: AdvertiseSettings, advertiseData: AdvertiseData, callback: AdvertiseCallback, /) -> None: ...
    @typing.overload
    def startAdvertising(self, settings: AdvertiseSettings, advertiseData: AdvertiseData, scanResponse: AdvertiseData, callback: AdvertiseCallback, /) -> None: ...
    @typing.overload
    def startAdvertisingSet(self, parameters: AdvertisingSetParameters, advertiseData: AdvertiseData, scanResponse: AdvertiseData, periodicParameters: PeriodicAdvertisingParameters, periodicData: AdvertiseData, callback: AdvertisingSetCallback, /) -> None: ...
    @typing.overload
    def startAdvertisingSet(self, parameters: AdvertisingSetParameters, advertiseData: AdvertiseData, scanResponse: AdvertiseData, periodicParameters: PeriodicAdvertisingParameters, periodicData: AdvertiseData, callback: AdvertisingSetCallback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def startAdvertisingSet(self, parameters: AdvertisingSetParameters, advertiseData: AdvertiseData, scanResponse: AdvertiseData, periodicParameters: PeriodicAdvertisingParameters, periodicData: AdvertiseData, duration: int | java.jint | java.lang.Integer, maxExtendedAdvertisingEvents: int | java.jint | java.lang.Integer, callback: AdvertisingSetCallback, /) -> None: ...
    @typing.overload
    def startAdvertisingSet(self, parameters: AdvertisingSetParameters, advertiseData: AdvertiseData, scanResponse: AdvertiseData, periodicParameters: PeriodicAdvertisingParameters, periodicData: AdvertiseData, duration: int | java.jint | java.lang.Integer, maxExtendedAdvertisingEvents: int | java.jint | java.lang.Integer, callback: AdvertisingSetCallback, handler: android.os.Handler, /) -> None: ...
    def stopAdvertising(self, callback: AdvertiseCallback, /) -> None: ...
    def stopAdvertisingSet(self, callback: AdvertisingSetCallback, /) -> None: ...

class BluetoothLeScanner(java.lang.Object):
    EXTRA_CALLBACK_TYPE: typing.ClassVar[str] = ...
    EXTRA_ERROR_CODE: typing.ClassVar[str] = ...
    EXTRA_LIST_SCAN_RESULT: typing.ClassVar[str] = ...
    def flushPendingScanResults(self, callback: ScanCallback, /) -> None: ...
    @typing.overload
    def startScan(self, callback: ScanCallback, /) -> None: ...
    @typing.overload
    def startScan(self, filters: java.util.List[ScanFilter], settings: ScanSettings, callbackIntent: android.app.PendingIntent, /) -> int: ...
    @typing.overload
    def startScan(self, filters: java.util.List[ScanFilter], settings: ScanSettings, callback: ScanCallback, /) -> None: ...
    @typing.overload
    def stopScan(self, callbackIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def stopScan(self, callback: ScanCallback, /) -> None: ...

class PeriodicAdvertisingParameters(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PeriodicAdvertisingParameters]] = ...
    def describeContents(self) -> int: ...
    def getIncludeTxPower(self) -> bool: ...
    def getInterval(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PeriodicAdvertisingParameters: ...
        def setIncludeTxPower(self, includeTxPower: bool | java.jboolean | java.lang.Boolean, /) -> PeriodicAdvertisingParameters.Builder: ...
        def setInterval(self, interval: int | java.jint | java.lang.Integer, /) -> PeriodicAdvertisingParameters.Builder: ...

class ScanCallback(java.lang.Object):
    SCAN_FAILED_ALREADY_STARTED: typing.ClassVar[int] = ...
    SCAN_FAILED_APPLICATION_REGISTRATION_FAILED: typing.ClassVar[int] = ...
    SCAN_FAILED_FEATURE_UNSUPPORTED: typing.ClassVar[int] = ...
    SCAN_FAILED_INTERNAL_ERROR: typing.ClassVar[int] = ...
    SCAN_FAILED_OUT_OF_HARDWARE_RESOURCES: typing.ClassVar[int] = ...
    SCAN_FAILED_SCANNING_TOO_FREQUENTLY: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onBatchScanResults(self, results: java.util.List[ScanResult], /) -> None: ...
    def onScanFailed(self, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onScanResult(self, callbackType: int | java.jint | java.lang.Integer, result: ScanResult, /) -> None: ...

class ScanFilter(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ScanFilter]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdvertisingData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getAdvertisingDataMask(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getAdvertisingDataType(self) -> int: ...
    def getDeviceAddress(self) -> str | None: ...
    def getDeviceName(self) -> str | None: ...
    def getManufacturerData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getManufacturerDataMask(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getManufacturerId(self) -> int: ...
    def getServiceData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getServiceDataMask(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getServiceDataUuid(self) -> android.os.ParcelUuid | None: ...
    def getServiceSolicitationUuid(self) -> android.os.ParcelUuid | None: ...
    def getServiceSolicitationUuidMask(self) -> android.os.ParcelUuid | None: ...
    def getServiceUuid(self) -> android.os.ParcelUuid | None: ...
    def getServiceUuidMask(self) -> android.os.ParcelUuid | None: ...
    def hashCode(self) -> int: ...
    def matches(self, scanResult: ScanResult, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ScanFilter: ...
        def setAdvertisingDataType(self, advertisingDataType: int | java.jint | java.lang.Integer, /) -> ScanFilter.Builder: ...
        def setAdvertisingDataTypeWithData(self, advertisingDataType: int | java.jint | java.lang.Integer, advertisingData: java.chaquopy.JavaArrayJByte, advertisingDataMask: java.chaquopy.JavaArrayJByte, /) -> ScanFilter.Builder: ...
        def setDeviceAddress(self, deviceAddress: str | java.lang.String, /) -> ScanFilter.Builder: ...
        def setDeviceName(self, deviceName: str | java.lang.String, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setManufacturerData(self, manufacturerId: int | java.jint | java.lang.Integer, manufacturerData: java.chaquopy.JavaArrayJByte, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setManufacturerData(self, manufacturerId: int | java.jint | java.lang.Integer, manufacturerData: java.chaquopy.JavaArrayJByte, manufacturerDataMask: java.chaquopy.JavaArrayJByte, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceData(self, serviceDataUuid: android.os.ParcelUuid, serviceData: java.chaquopy.JavaArrayJByte, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceData(self, serviceDataUuid: android.os.ParcelUuid, serviceData: java.chaquopy.JavaArrayJByte, serviceDataMask: java.chaquopy.JavaArrayJByte, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceSolicitationUuid(self, serviceSolicitationUuid: android.os.ParcelUuid, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceSolicitationUuid(self, serviceSolicitationUuid: android.os.ParcelUuid, solicitationUuidMask: android.os.ParcelUuid, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceUuid(self, serviceUuid: android.os.ParcelUuid, /) -> ScanFilter.Builder: ...
        @typing.overload
        def setServiceUuid(self, serviceUuid: android.os.ParcelUuid, uuidMask: android.os.ParcelUuid, /) -> ScanFilter.Builder: ...

class ScanRecord(java.lang.Object):
    DATA_TYPE_3D_INFORMATION_DATA: typing.ClassVar[int] = ...
    DATA_TYPE_ADVERTISING_INTERVAL: typing.ClassVar[int] = ...
    DATA_TYPE_ADVERTISING_INTERVAL_LONG: typing.ClassVar[int] = ...
    DATA_TYPE_APPEARANCE: typing.ClassVar[int] = ...
    DATA_TYPE_BIG_INFO: typing.ClassVar[int] = ...
    DATA_TYPE_BROADCAST_CODE: typing.ClassVar[int] = ...
    DATA_TYPE_CHANNEL_MAP_UPDATE_INDICATION: typing.ClassVar[int] = ...
    DATA_TYPE_CLASS_OF_DEVICE: typing.ClassVar[int] = ...
    DATA_TYPE_DEVICE_ID: typing.ClassVar[int] = ...
    DATA_TYPE_FLAGS: typing.ClassVar[int] = ...
    DATA_TYPE_INDOOR_POSITIONING: typing.ClassVar[int] = ...
    DATA_TYPE_LE_BLUETOOTH_DEVICE_ADDRESS: typing.ClassVar[int] = ...
    DATA_TYPE_LE_ROLE: typing.ClassVar[int] = ...
    DATA_TYPE_LE_SECURE_CONNECTIONS_CONFIRMATION_VALUE: typing.ClassVar[int] = ...
    DATA_TYPE_LE_SECURE_CONNECTIONS_RANDOM_VALUE: typing.ClassVar[int] = ...
    DATA_TYPE_LE_SUPPORTED_FEATURES: typing.ClassVar[int] = ...
    DATA_TYPE_LOCAL_NAME_COMPLETE: typing.ClassVar[int] = ...
    DATA_TYPE_LOCAL_NAME_SHORT: typing.ClassVar[int] = ...
    DATA_TYPE_MANUFACTURER_SPECIFIC_DATA: typing.ClassVar[int] = ...
    DATA_TYPE_MESH_BEACON: typing.ClassVar[int] = ...
    DATA_TYPE_MESH_MESSAGE: typing.ClassVar[int] = ...
    DATA_TYPE_NONE: typing.ClassVar[int] = ...
    DATA_TYPE_PB_ADV: typing.ClassVar[int] = ...
    DATA_TYPE_PUBLIC_TARGET_ADDRESS: typing.ClassVar[int] = ...
    DATA_TYPE_RANDOM_TARGET_ADDRESS: typing.ClassVar[int] = ...
    DATA_TYPE_RESOLVABLE_SET_IDENTIFIER: typing.ClassVar[int] = ...
    DATA_TYPE_SECURITY_MANAGER_OUT_OF_BAND_FLAGS: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_DATA_128_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_DATA_16_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_DATA_32_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_SOLICITATION_UUIDS_128_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_SOLICITATION_UUIDS_16_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_SOLICITATION_UUIDS_32_BIT: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_128_BIT_COMPLETE: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_128_BIT_PARTIAL: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_16_BIT_COMPLETE: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_16_BIT_PARTIAL: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_32_BIT_COMPLETE: typing.ClassVar[int] = ...
    DATA_TYPE_SERVICE_UUIDS_32_BIT_PARTIAL: typing.ClassVar[int] = ...
    DATA_TYPE_SIMPLE_PAIRING_HASH_C: typing.ClassVar[int] = ...
    DATA_TYPE_SIMPLE_PAIRING_HASH_C_256: typing.ClassVar[int] = ...
    DATA_TYPE_SIMPLE_PAIRING_RANDOMIZER_R: typing.ClassVar[int] = ...
    DATA_TYPE_SIMPLE_PAIRING_RANDOMIZER_R_256: typing.ClassVar[int] = ...
    DATA_TYPE_SLAVE_CONNECTION_INTERVAL_RANGE: typing.ClassVar[int] = ...
    DATA_TYPE_TRANSPORT_DISCOVERY_DATA: typing.ClassVar[int] = ...
    DATA_TYPE_TX_POWER_LEVEL: typing.ClassVar[int] = ...
    DATA_TYPE_URI: typing.ClassVar[int] = ...
    def getAdvertiseFlags(self) -> int: ...
    def getAdvertisingDataMap(self) -> java.util.Map[java.lang.Integer, java.chaquopy.JavaArrayJByte]: ...
    def getBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def getDeviceName(self) -> str | None: ...
    @typing.overload
    def getManufacturerSpecificData(self) -> android.util.SparseArray[java.chaquopy.JavaArrayJByte] | None: ...
    @typing.overload
    def getManufacturerSpecificData(self, manufacturerId: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    @typing.overload
    def getServiceData(self) -> java.util.Map[android.os.ParcelUuid, java.chaquopy.JavaArrayJByte]: ...
    @typing.overload
    def getServiceData(self, serviceDataUuid: android.os.ParcelUuid, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getServiceSolicitationUuids(self) -> java.util.List[android.os.ParcelUuid]: ...
    def getServiceUuids(self) -> java.util.List[android.os.ParcelUuid] | None: ...
    def getTxPowerLevel(self) -> int: ...
    def toString(self) -> str: ...

class ScanResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ScanResult]] = ...
    DATA_COMPLETE: typing.ClassVar[int] = ...
    DATA_TRUNCATED: typing.ClassVar[int] = ...
    PERIODIC_INTERVAL_NOT_PRESENT: typing.ClassVar[int] = ...
    PHY_UNUSED: typing.ClassVar[int] = ...
    SID_NOT_PRESENT: typing.ClassVar[int] = ...
    TX_POWER_NOT_PRESENT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, device: android.bluetooth.BluetoothDevice, scanRecord: ScanRecord, rssi: int | java.jint | java.lang.Integer, timestampNanos: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, device: android.bluetooth.BluetoothDevice, eventType: int | java.jint | java.lang.Integer, primaryPhy: int | java.jint | java.lang.Integer, secondaryPhy: int | java.jint | java.lang.Integer, advertisingSid: int | java.jint | java.lang.Integer, txPower: int | java.jint | java.lang.Integer, rssi: int | java.jint | java.lang.Integer, periodicAdvertisingInterval: int | java.jint | java.lang.Integer, scanRecord: ScanRecord, timestampNanos: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdvertisingSid(self) -> int: ...
    def getDataStatus(self) -> int: ...
    def getDevice(self) -> android.bluetooth.BluetoothDevice: ...
    def getPeriodicAdvertisingInterval(self) -> int: ...
    def getPrimaryPhy(self) -> int: ...
    def getRssi(self) -> int: ...
    def getScanRecord(self) -> ScanRecord | None: ...
    def getSecondaryPhy(self) -> int: ...
    def getTimestampNanos(self) -> int: ...
    def getTxPower(self) -> int: ...
    def hashCode(self) -> int: ...
    def isConnectable(self) -> bool: ...
    def isLegacy(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ScanSettings(android.os.Parcelable):
    AUTO_BATCH_MIN_REPORT_DELAY_MILLIS: typing.ClassVar[int] = ...
    CALLBACK_TYPE_ALL_MATCHES: typing.ClassVar[int] = ...
    CALLBACK_TYPE_ALL_MATCHES_AUTO_BATCH: typing.ClassVar[int] = ...
    CALLBACK_TYPE_FIRST_MATCH: typing.ClassVar[int] = ...
    CALLBACK_TYPE_MATCH_LOST: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ScanSettings]] = ...
    MATCH_MODE_AGGRESSIVE: typing.ClassVar[int] = ...
    MATCH_MODE_STICKY: typing.ClassVar[int] = ...
    MATCH_NUM_FEW_ADVERTISEMENT: typing.ClassVar[int] = ...
    MATCH_NUM_MAX_ADVERTISEMENT: typing.ClassVar[int] = ...
    MATCH_NUM_ONE_ADVERTISEMENT: typing.ClassVar[int] = ...
    PHY_LE_ALL_SUPPORTED: typing.ClassVar[int] = ...
    SCAN_MODE_BALANCED: typing.ClassVar[int] = ...
    SCAN_MODE_LOW_LATENCY: typing.ClassVar[int] = ...
    SCAN_MODE_LOW_POWER: typing.ClassVar[int] = ...
    SCAN_MODE_OPPORTUNISTIC: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getCallbackType(self) -> int: ...
    def getLegacy(self) -> bool: ...
    def getPhy(self) -> int: ...
    def getReportDelayMillis(self) -> int: ...
    def getScanMode(self) -> int: ...
    def getScanResultType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ScanSettings: ...
        def setCallbackType(self, callbackType: int | java.jint | java.lang.Integer, /) -> ScanSettings.Builder: ...
        def setLegacy(self, legacy: bool | java.jboolean | java.lang.Boolean, /) -> ScanSettings.Builder: ...
        def setMatchMode(self, matchMode: int | java.jint | java.lang.Integer, /) -> ScanSettings.Builder: ...
        def setNumOfMatches(self, numOfMatches: int | java.jint | java.lang.Integer, /) -> ScanSettings.Builder: ...
        def setPhy(self, phy: int | java.jint | java.lang.Integer, /) -> ScanSettings.Builder: ...
        def setReportDelay(self, reportDelayMillis: int | java.jlong | java.lang.Long, /) -> ScanSettings.Builder: ...
        def setScanMode(self, scanMode: int | java.jint | java.lang.Integer, /) -> ScanSettings.Builder: ...

class TransportBlock(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TransportBlock]] = ...
    def __init__(self, orgId: int | java.jint | java.lang.Integer, tdsFlags: int | java.jint | java.lang.Integer, transportDataLength: int | java.jint | java.lang.Integer, transportData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOrgId(self) -> int: ...
    def getTdsFlags(self) -> int: ...
    def getTransportData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getTransportDataLength(self) -> int: ...
    def hashCode(self) -> int: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def totalBytes(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TransportDiscoveryData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TransportDiscoveryData]] = ...
    @typing.overload
    def __init__(self, transportDiscoveryData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, transportDataType: int | java.jint | java.lang.Integer, transportBlocks: java.util.List[TransportBlock], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getTransportBlocks(self) -> java.util.List[TransportBlock]: ...
    def getTransportDataType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def toString(self) -> str: ...
    def totalBytes(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
